DtnClient

Struct DtnClient 

pub struct DtnClient { /* private fields */ }
Client for connecting to a local dtnd instance

Works with IPv6 and IPv4.

Implementations

Source

impl DtnClient

pub fn new() -> Self

Constructs a new client for 127.0.0.1 on port 3000.

pub fn with_host_and_port(localhost: String, port: u16) -> Self

New client with custom host and port

pub fn local_node_id(&self) -> Result<EndpointID, ClientError>

Return the local node ID via rest interface

pub fn creation_timestamp(&self) -> Result<CreationTimestamp, ClientError>

Get a new node-wide unique creation timestamp via rest interface

pub fn register_application_endpoint( &self, path: &str, ) -> Result<(), ClientError>

Register a new application endpoint at local node

pub fn unregister_application_endpoint( &self, path: &str, ) -> Result<(), ClientError>

Unregister an application endpoint at local node

pub fn ws(&self) -> Result<DtnWsConnection<TcpStream>>

Constructs a new websocket connection to the configured dtn7 client

pub fn ws_with_config( &self, config: WebSocketConfig, ) -> Result<DtnWsConnection<TcpStream>>

Constructs a new websocket connection to the configured dtn7 client with a custom WebSocketConfig

pub fn ws_custom<Stream>( &self, stream: Stream, ) -> Result<DtnWsConnection<Stream>>
where Stream: Read + Write,

Constructs a new websocket connection to the configured dtn7 client using a custom Stream

pub fn ws_custom_with_config<Stream>( &self, stream: Stream, config: WebSocketConfig, ) -> Result<DtnWsConnection<Stream>>
where Stream: Read + Write,

Constructs a new websocket connection to the configured dtn7 client using a custom Stream and a custom WebSocketConfig