DtnWsConnection

Struct DtnWsConnection 

pub struct DtnWsConnection<Stream>
where Stream: Read + Write,
{ /* private fields */ }

Implementations

Source

impl<Stream> DtnWsConnection<Stream>
where Stream: Read + Write,

pub fn write_text(&mut self, txt: &str) -> Result<()>

Send a text message via websocket

accepted commands: /data /bundle /subscribe <service>

pub fn write_binary(&mut self, bin: &[u8]) -> Result<()>

Send a binary message via websocket

Server expects either

  • a valid bundle (in bundle mode)
  • a WsSendData struct as a cbor buffer (in data mode)
pub fn read_message(&mut self) -> Result<Message>

Read the next message

Could be text, binary, ping, etc etc

pub fn read_text(&mut self) -> Result<String>

Expect a text message next, returning an error on any other message type

pub fn read_binary(&mut self) -> Result<Vec<u8>>

Expect a binary message next, returning an error on any other message type